@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2008 IBM Corporation and others.
+ * Copyright (c) 2000, 2009 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -24,7 +24,7 @@ public class Library {
 	/**
 	 * SWT Minor version number (must be in the range 0..999)
 	 */
-    static int MINOR_VERSION = 448;
+    static int MINOR_VERSION = 555;
 	
 	/**
 	 * SWT revision number (must be >= 0)
@@ -37,6 +37,12 @@ public class Library {
 	public static final int JAVA_VERSION, SWT_VERSION;
 
 	static final String SEPARATOR;
+	
+	/* 64-bit support */
+	static /*final*/ boolean IS_64 = 0x1FFFFFFFFL == (int /*long*/)0x1FFFFFFFFL;
+	static final String SUFFIX_64 = "-64";	//$NON-NLS-1$
+	static final String SWTDIR_32 = "swtlib-32";	//$NON-NLS-1$
+	static final String SWTDIR_64 = "swtlib-64";	//$NON-NLS-1$
 
 static {
 	SEPARATOR = System.getProperty("file.separator");
@@ -92,10 +98,12 @@ static boolean extract (String fileName, String mappedName) {
 	FileOutputStream os = null;
 	InputStream is = null;
 	File file = new File(fileName);
+	boolean extracted = false;
 	try {
 		if (!file.exists ()) {
 			is = Library.class.getResourceAsStream ("/" + mappedName); //$NON-NLS-1$
 			if (is != null) {
+				extracted = true;
 				int read;
 				byte [] buffer = new byte [4096];
 				os = new FileOutputStream (fileName);
@@ -109,9 +117,9 @@ static boolean extract (String fileName, String mappedName) {
 						Runtime.getRuntime ().exec (new String []{"chmod", "755", fileName}).waitFor(); //$NON-NLS-1$ //$NON-NLS-2$
 					} catch (Throwable e) {}
 				}
-				if (load (fileName)) return true;
 			}
 		}
+		if (load (fileName)) return true;
 	} catch (Throwable e) {
 		try {
 			if (os != null) os.close ();
@@ -119,8 +127,8 @@ static boolean extract (String fileName, String mappedName) {
 		try {
 			if (is != null) is.close ();
 		} catch (IOException e1) {}
+		if (extracted && file.exists ()) file.delete ();
 	}
-	if (file.exists ()) file.delete ();
 	return false;
 }
 
@@ -167,15 +175,11 @@ public static void loadLibrary (String name, boolean mapName) {
 	String prop = System.getProperty ("sun.arch.data.model"); //$NON-NLS-1$
 	if (prop == null) prop = System.getProperty ("com.ibm.vm.bitmode"); //$NON-NLS-1$
 	if (prop != null) {
-		if ("32".equals (prop)) { //$NON-NLS-1$
-			 if (0x1FFFFFFFFL == (int /*long*/)0x1FFFFFFFFL) {
-				throw new UnsatisfiedLinkError ("Cannot load 64-bit SWT libraries on 32-bit JVM"); //$NON-NLS-1$
-			 }
+		if ("32".equals (prop) && IS_64) { //$NON-NLS-1$
+			throw new UnsatisfiedLinkError ("Cannot load 64-bit SWT libraries on 32-bit JVM"); //$NON-NLS-1$
 		}
-		if ("64".equals (prop)) { //$NON-NLS-1$
-			if (0x1FFFFFFFFL != (int /*long*/)0x1FFFFFFFFL) {
-				throw new UnsatisfiedLinkError ("Cannot load 32-bit SWT libraries on 64-bit JVM"); //$NON-NLS-1$
-			}		
+		if ("64".equals (prop) && !IS_64) { //$NON-NLS-1$
+			throw new UnsatisfiedLinkError ("Cannot load 32-bit SWT libraries on 64-bit JVM"); //$NON-NLS-1$
 		}
 	}
 	
@@ -197,8 +201,8 @@ public static void loadLibrary (String name, boolean mapName) {
 		}
 		libName1 = name + "-" + Platform.PLATFORM + "-" + version;  //$NON-NLS-1$ //$NON-NLS-2$
 		libName2 = name + "-" + Platform.PLATFORM;  //$NON-NLS-1$
-		mappedName1 = System.mapLibraryName (libName1);
-		mappedName2 = System.mapLibraryName (libName2);
+		mappedName1 = mapLibraryName (libName1);
+		mappedName2 = mapLibraryName (libName2);
 	} else {
 		libName1 = libName2 = mappedName1 = mappedName2 = name;
 	}
@@ -214,23 +218,50 @@ public static void loadLibrary (String name, boolean mapName) {
 	/* Try loading library from java library path */
 	if (load (libName1)) return;
 	if (mapName && load (libName2)) return;
-	
+
 	/* Try loading library from the tmp directory if swt library path is not specified */
+	String fileName1 = mappedName1;
+	String fileName2 = mappedName2;
 	if (path == null) {
 		path = System.getProperty ("java.io.tmpdir"); //$NON-NLS-1$
-		path = new File (path).getAbsolutePath ();
-		if (load (path + SEPARATOR + mappedName1)) return;
-		if (mapName && load (path + SEPARATOR + mappedName2)) return;
+		File dir = new File (path, IS_64 ? SWTDIR_64 : SWTDIR_32);
+		boolean make = false;
+		if ((dir.exists () && dir.isDirectory ()) || (make = dir.mkdir ())) {
+			path = dir.getAbsolutePath ();
+			if (make && !Platform.PLATFORM.equals ("win32")) { //$NON-NLS-1$
+				try {
+					Runtime.getRuntime ().exec (new String []{"chmod", "777", path}).waitFor(); //$NON-NLS-1$ //$NON-NLS-2$
+				} catch (Throwable e) {}
+			}
+		} else {
+			/* fall back to using the tmp directory */
+			if (IS_64) {
+				fileName1 = mapLibraryName (libName1 + SUFFIX_64);
+				fileName2 = mapLibraryName (libName2 + SUFFIX_64);
+			}
+		}
+		if (load (path + SEPARATOR + fileName1)) return;
+		if (mapName && load (path + SEPARATOR + fileName2)) return;
 	}
 		
 	/* Try extracting and loading library from jar */
 	if (path != null) {
-		if (extract (path + SEPARATOR + mappedName1, mappedName1)) return;
-		if (mapName && extract (path + SEPARATOR + mappedName2, mappedName2)) return;
+		if (extract (path + SEPARATOR + fileName1, mappedName1)) return;
+		if (mapName && extract (path + SEPARATOR + fileName2, mappedName2)) return;
 	}
 	
 	/* Failed to find the library */
 	throw new UnsatisfiedLinkError ("no " + libName1 + " or " + libName2 + " in swt.library.path, java.library.path or the jar file"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 }
 
+static String mapLibraryName (String libName) {
+	/* SWT libraries in the Macintosh use the extension .jnilib but the some VMs map to .dylib. */
+	libName = System.mapLibraryName (libName);
+	String ext = ".dylib"; //$NON-NLS-1$
+	if (libName.endsWith(ext)) {
+		libName = libName.substring(0, libName.length() - ext.length()) + ".jnilib"; //$NON-NLS-1$
+	}
+	return libName;
+}
+
 }
